@@ -737,7 +737,8 @@ sub todo_tests_default {
     push @todo, (103)  if $] < 5.007 or $] >= 5.010;
     #push @todo, (29)   if $] >= 5.010 and !$DEBUGGING;
     #push @todo, (29)   if $] >= 5.013006;
-    #push @todo, (15) if !$ITHREADS;
+    push @todo, (15);
+    push @todo, (7)   if $] eq '5.008005';
     # 15 passes on cygwin XP, but fails on cygwin Win7
     if ($what =~ /^c(|_o[1-4])$/) {
         # 14+23 fixed with 1.04_29, for 5.10 with 1.04_31
@@ -751,6 +752,7 @@ sub todo_tests_default {
         # push @todo, (39)   if $] > 5.007 and $] < 5.009;
         # fixed with 1.30
         # push @todo, (21)   if $] > 5.011 and $] < 5.013;
+        push @todo, (29)   if $] > 5.009 and $] < 5.012;
         push @todo, (28,48) if $what =~ /c_o[34]/;
         push @todo, (21)   if $] > 5.011 and $] <= 5.013006;
         #push @todo, (25)   if $] =~ /5\.012/ and $DEBUGGING and $ITHREADS; # linux only
@@ -758,23 +760,24 @@ sub todo_tests_default {
         push @todo, (16,29,44,45,49) if $] > 5.013 and !$DEBUGGING and !$ITHREADS;
         push @todo, (10,12,16) if $what =~ /c_o[234]/ and $] >= 5.010;
         push @todo, (11)    if $what =~ /c_o[234]/ and $] < 5.010;
-        push @todo, (15,44,45) if $what =~ /c_o[1234]/;
+        push @todo, (44,45) if $what =~ /c_o[1234]/;
         push @todo, (50)    if $what =~ /c_o[234]/;
         push @todo, (19)    if $what eq 'c_o2' and $ITHREADS;
 	push @todo, (10,12,19,25) if $what eq 'c_o4';
     } elsif ($what =~ /^cc/) {
         # 8,11,14..16,18..19 fail on 5.00505 + 5.6, old core failures (max 20)
         # on cygwin 29 passes
+	push @todo, (3,16)  if $] eq '5.008005';
         push @todo, (35); # fixed 44 -nt
         push @todo, (21,30); #5.8.9
         push @todo, (44)    if $ITHREADS or $] < 5.012;
-        #push @todo, (44)    if !$ITHREADS and $] >= 5.012;
+        #push @todo, (44)   if !$ITHREADS and $] >= 5.012;
         push @todo, (105)   if $what =~ /^cc(_o1)?/ or ($] > 5.008005 and $] < 5.010);
         push @todo, (10,16) if $what eq 'cc_o2';
         push @todo, (27)    if $] < 5.007 and $what eq 'cc_o2';
         push @todo, (104)   if $] < 5.007; # leaveloop, no cxstack
-        push @todo, (11,15,45,103,105) if $] > 5.007 and $] < 5.009;
-        push @todo, (15,29) if $] > 5.009 and $] < 5.011;
+        push @todo, (11,45,103,105) if $] > 5.007 and $] < 5.009;
+        push @todo, (29)    if $] < 5.008006 or ($] > 5.013 and !$ITHREADS);
         #push @todo, (11,27) if $] < 5.009;
         push @todo, (14)    if $] >= 5.010 and $^O !~ /MSWin32|cygwin/i;
         # solaris also. I suspected nvx<=>cop_seq_*
@@ -782,7 +785,7 @@ sub todo_tests_default {
         #push @todo, (3,4,27,42,43) if $] >= 5.011004 and $ITHREADS;
         push @todo, (26)    if $what =~ /^cc_o[12]/;
         push @todo, (27)    if $] < 5.010 and $what eq 'cc_o2';
-        #push @todo, (15)    if ($] >= 5.012 or $] < 5.010) and $ITHREADS;
+        push @todo, (15)    if $] > 5.011 and $] < 5.013;
         push @todo, (25)    if $] >= 5.011004 and $DEBUGGING and $ITHREADS;
         push @todo, (3,4)   if $] >= 5.011004 and $ITHREADS;
         push @todo, (103)   if $] >= 5.012 and $ITHREADS;
